==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/websrc/Login.php <==
<?php /* Copyright (C) 2006, 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007, 2008 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php
  /*
list($sovix__ip_address1, $sovix__ip_address2, $sovix__ip_address3, $sovix__ip_address4, $sovix__ip_address5, $sovix__ip_address6, $sovix__ip_address7, $sovix__ip_address8, $sovix__ip_address9, $sovix__ip_address10, ) = split('[ ]', $sovix__ip_address);
if ("$sovix__ip_address"=="Allow from all" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address1" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address2" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address3" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address4" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address5" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address6" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address7" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address8" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address9" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address10"
) $sovix__accept="y";
  */

$sovix__try_login=$_POST['sovix__try_login'];

if($sovix__try_login=="y") {

    for($sovix__i = 0; $sovix__i < count($sovix__array__auth_sovix); $sovix__i++) {
      if (
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__username']}"==$_POST['sovix__submited_username'] && 
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__password']}"==""
	  ) {
	echo "<span style=\"color:#ff0000;\">No password or username supplied by</span> <font color=\"#0000BB\">\$sovix__file__auth_sovix</font>.";
	echo "<br />You might want to try a URL who use another configuration file?";
      }
    }

$sovix__somecontent = "Date: ".date("Y-m-d h:m:s")."\nIP: ".$_SERVER['REMOTE_ADDR']."\nWebbrowser: ".$_SERVER['HTTP_USER_AGENT']."\nSubmited username: ".$_POST['sovix__submited_username']."\nSubmited password: ".$_POST['sovix__submited_password']."\n\n";

  if (is_writable($sovix__file__log)) {
    if (!$sovix__handle = fopen($sovix__file__log, 'a')) {
      echo "Cannot open file ($sovix__file__log)";
      exit;
    }
   
    if (fwrite($sovix__handle, $sovix__somecontent) === FALSE) {
      echo "Cannot write to file ($sovix__file__log)";
      exit;
    }
   
    fclose($sovix__handle);

  } else {
    echo "The file $sovix__file__log is not writable";
  }

    for($sovix__i = 0; $sovix__i < count($sovix__array__auth_sovix); $sovix__i++) {
      if (
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__username']}"==$_POST['sovix__submited_username'] && 
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__password']}"==$_POST['sovix__submited_password'] &&
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__ip_address']}"=="Allow from all" ||
	  strpos("{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__ip_address']}", $_SERVER['REMOTE_ADDR']) !== false
	  ) {
	$_SESSION['sovix__logged_in']="y";
	$_SESSION['sovix__user']=$_POST['sovix__submited_username'];
      }
    }

  if ($_POST['sovix__submited_password']=="") echo "<span style=\"color:#ff0000;\">You must enter a password.</span><br />";
  if ($_POST['sovix__submited_username']=="") echo "<span style=\"color:#ff0000;\">You must enter a username.</span><br />";
  if (!isset($_SESSION['sovix__user'])) echo "<span style=\"color:#ff0000;\">Sorry, try again.</span>";
 }

if (isset($_SESSION['sovix__user']))
{
  echo "
<span style=\"color:#00ff00;\">You are logged which means that you have previlegies over this website.</span><p></p>
Avalible commands for ".$_SESSION['sovix__user'].":<br />";
require "$sovix__directory__src/commands.inc";
for($sovix__i = 0; $sovix__i < count($sovix__array__commands); $sovix__i++) {
  if ("{$sovix__array__commands[$sovix__i]['sovix__array__commands__require']}"!="None" && "{$sovix__array__commands[$sovix__i]['sovix__array__commands__require']}") echo "<a href=\"?action={$sovix__array__commands[$sovix__i]['sovix__array__commands__command']}#footer\">{$sovix__array__commands[$sovix__i]['sovix__array__commands__command']}</a><br />";
 }
 
 echo "<p></p>
Manage PostgreSQL and MySQL via Sovix web template engine:<br />";
 if ($_SESSION['sovix__user']=="root") echo "Insert querys<br />";
 echo "Update querys<br />";
 if ($_SESSION['sovix__user']=="root") echo "Drop querys<br />";
 echo "<p></p>";
 }
 else {
  ?>
   <p></p>
 <form action="" method="post">
<input type="hidden" name="sovix__try_login" value="y" />
<table align="center" cellspacing="10">
  <tr>
    <td colspan="2" align="center"><img src="<?php echo "$sovix__url__websrc/images"; ?>/heckert_gnu.small.png" /></td>
  </tr>
  <tr>
    <td>Directory:</td>
    <td><?php echo "$sovix__directory__dotsovix/"; ?>
  </tr>
  <tr>
    <td>Username:</td>
    <td><input type="password" name="sovix__submited_username" size="50" /></td><!-- Let the value of size be, it is confusing to not see what one writes if there is much text. -->
  </tr>
  <tr>
    <td>Password:</td>
    <td><input type="password" name="sovix__submited_password" size="50" /></td><!-- Let the value of size be, it is confusing to not see what one writes if there is much text. -->
  </tr>
  <tr>
    <td></td>
    <td><input type="submit" value="Submit" alt="Make monthly online donations with PayPal - it's fast, free and secure!" style="background-image:url(<?php echo "$sovix__url__websrc/images"; ?>/button.png); border-style:none; width:90px; height:21px;" /></td>
  </tr>
</table>

</form>

    <?php
    }
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6.tar.gz: sovix-0.0.1.6/websrc/Login.php <==
<?php /* Copyright (C) 2006, 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007, 2008 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php
  /*
list($sovix__ip_address1, $sovix__ip_address2, $sovix__ip_address3, $sovix__ip_address4, $sovix__ip_address5, $sovix__ip_address6, $sovix__ip_address7, $sovix__ip_address8, $sovix__ip_address9, $sovix__ip_address10, ) = split('[ ]', $sovix__ip_address);
if ("$sovix__ip_address"=="Allow from all" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address1" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address2" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address3" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address4" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address5" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address6" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address7" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address8" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address9" ||
$_SERVER['REMOTE_ADDR']=="$sovix__ip_address10"
) $sovix__accept="y";
  */

$sovix__try_login=$_POST['sovix__try_login'];

if($sovix__try_login=="y") {

    for($sovix__i = 0; $sovix__i < count($sovix__array__auth_sovix); $sovix__i++) {
      if (
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__username']}"==$_POST['sovix__submited_username'] && 
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__password']}"==""
	  ) {
	echo "<span style=\"color:#ff0000;\">No password or username supplied by</span> <font color=\"#0000BB\">\$sovix__file__auth_sovix</font>.";
	echo "<br />You might want to try a URL who use another configuration file?";
      }
    }

$sovix__somecontent = "<? /*\nDate: ".date("Y-m-d h:m:s")."\nIP: ".$_SERVER['REMOTE_ADDR']."\nWebbrowser: ".$_SERVER['HTTP_USER_AGENT']."\nSubmited username: ".$_POST['sovix__submited_username']."\nSubmited password: ".$_POST['sovix__submited_password']."\n*/ ?>\n";

  if (is_writable($sovix__file__log)) {
    if (!$sovix__handle = fopen($sovix__file__log, 'a')) {
      echo "Cannot open file ($sovix__file__log)";
      exit;
    }
   
    if (fwrite($sovix__handle, $sovix__somecontent) === FALSE) {
      echo "Cannot write to file ($sovix__file__log)";
      exit;
    }
   
    fclose($sovix__handle);

  } else {
    echo "The file $sovix__file__log is not writable";
  }

    for($sovix__i = 0; $sovix__i < count($sovix__array__auth_sovix); $sovix__i++) {
      if (
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__username']}"==$_POST['sovix__submited_username'] && 
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__password']}"==$_POST['sovix__submited_password'] &&
	  "{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__ip_address']}"=="Allow from all" ||
	  strpos("{$sovix__array__auth_sovix[$sovix__i]['sovix__array__auth_sovix__ip_address']}", $_SERVER['REMOTE_ADDR']) !== false
	  ) {
	$_SESSION['sovix__logged_in']="y";
	$_SESSION['sovix__user']=$_POST['sovix__submited_username'];
      }
    }

  if ($_POST['sovix__submited_password']=="") echo "<span style=\"color:#ff0000;\">You must enter a password.</span><br />";
  if ($_POST['sovix__submited_username']=="") echo "<span style=\"color:#ff0000;\">You must enter a username.</span><br />";
  if (!isset($_SESSION['sovix__user'])) echo "<span style=\"color:#ff0000;\">Sorry, try again.</span>";
 }

if (isset($_SESSION['sovix__user']))
{
  echo "
<span style=\"color:#00ff00;\">You are logged which means that you have previlegies over this website.</span><p></p>
Avalible commands for ".$_SESSION['sovix__user'].":<br />";
require "$sovix__directory__src/commands.inc";
for($sovix__i = 0; $sovix__i < count($sovix__array__commands); $sovix__i++) {
  if ("{$sovix__array__commands[$sovix__i]['sovix__array__commands__require']}"!="None" && "{$sovix__array__commands[$sovix__i]['sovix__array__commands__require']}") echo "<a href=\"?action={$sovix__array__commands[$sovix__i]['sovix__array__commands__command']}#footer\">{$sovix__array__commands[$sovix__i]['sovix__array__commands__command']}</a><br />";
 }
 
 echo "<p></p>
Manage PostgreSQL and MySQL via Sovix web template engine:<br />";
 if ($_SESSION['sovix__user']=="root") echo "Insert querys<br />";
 echo "Update querys<br />";
 if ($_SESSION['sovix__user']=="root") echo "Drop querys<br />";
 echo "<p></p>";
 }
 else {
  ?>
   <p></p>
 <form action="" method="post">
<input type="hidden" name="sovix__try_login" value="y" />
<table align="center" cellspacing="10">
  <tr>
    <td colspan="2" align="center"><img src="<?php echo "$sovix__url__websrc/images"; ?>/heckert_gnu.small.png" /></td>
  </tr>
  <tr>
    <td>Directory:</td>
    <td><?php echo "$sovix__directory__dotsovix/"; ?>
  </tr>
  <tr>
    <td>Username:</td>
    <td><input type="password" name="sovix__submited_username" size="50" /></td><!-- Let the value of size be, it is confusing to not see what one writes if there is much text. -->
  </tr>
  <tr>
    <td>Password:</td>
    <td><input type="password" name="sovix__submited_password" size="50" /></td><!-- Let the value of size be, it is confusing to not see what one writes if there is much text. -->
  </tr>
  <tr>
    <td></td>
    <td><input type="submit" value="Submit" alt="Make monthly online donations with PayPal - it's fast, free and secure!" style="background-image:url(<?php echo "$sovix__url__websrc/images"; ?>/button.png); border-style:none; width:90px; height:21px;" /></td>
  </tr>
</table>

</form>

    <?php
    }
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>
